@@ -73,6 +73,8 @@ using namespace KBabel;
 Catalog::Catalog(QObject* parent, const char* name, QString projectFile)
         : QObject(parent,name)
 {
+   if ( projectFile.isEmpty() )
+        projectFile = KBabel::ProjectManager::defaultProjectName();
    d = new CatalogPrivate(ProjectManager::open(projectFile));
    readPreferences();
 }
@@ -345,6 +347,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
          {
             (*it) = temp;
             found=true;
+            break;
          }
        }
        if(!found)
@@ -364,6 +367,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
          {
             (*it) = temp;
             found=true;
+            break;
          }
        }
        if(!found)
@@ -384,6 +388,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
          {
             (*it) = temp;
             found=true;
+            break;
          }
        }
        if(!found)
@@ -407,6 +412,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
          {
             (*it) = temp;
             found=true;
+            break;
          }
        }
        if(!found)
@@ -416,6 +422,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
    }
     if(!usePrefs || saveOptions.updateCharset)
     {
+        
         found=false;
     
         QString encodingStr;
@@ -427,6 +434,9 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
         {
             encodingStr=charsetString(saveOptions.encoding);
         }
+
+        temp = "Content-Type: text/plain; charset=" + encodingStr + "\\n";
+                
         it = headerList.begin();
         while( it != headerList.end() )
         {
@@ -477,6 +487,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
          {
             (*it) = temp;
             found=true;
+            break;
          }
        }
        if(!found)
@@ -495,6 +506,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
       {
          (*it) = temp;
          found=true;
+         break;
       }
     }
     if(!found)
@@ -511,6 +523,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
     	{
          (*it) = temp;
          found=true;
+         break;
     	}
    }
    if( !found )
@@ -532,6 +545,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
     	    {
         	(*it) = temp;
         	found=true;
+                break;
     	    }
 	}
         if( !found )
@@ -601,7 +615,7 @@ CatalogItem Catalog::updatedHeader(CatalogItem oldHeader, bool usePrefs) const
         QRegExp regexp ( regexpstr );
 
         // The buggy variants exist in English too (of a time before KBabel got a translation for the corresponding language)
-        QRegExp regexpUntranslated ( "^#\\s+translation of .* to .*\\s*$" );
+        QRegExp regexpUntranslated ( "^#\\s+Translation of .* into .*\\s*$" );
 
         kdDebug () << "Temp is '" << temp << "'" << endl;
 
@@ -2382,6 +2396,7 @@ void Catalog::applyEndCommand(uint index, Part part, CatalogView* view)
 
 void Catalog::processCommand(EditCommand* cmd,CatalogView* view, bool undo)
 {
+    kdDebug(KBABEL) << "Catalog::processCommand()" << endl;
     if(cmd->terminator()==0)
     {
        bool checkUntranslated=false;
@@ -2486,7 +2501,7 @@ bool Catalog::findNext(const FindOptions* findOpts, DocPosition& docPos, int& le
 	bool success = false; // true, when string found
 	bool endReached=false;
 
-	kdDebug(KBABEL) << "findNext active" << endl;
+       kdDebug(KBABEL) << "findNext active" << endl;
 	d->_active=true;
 	d->_stop=false;
 	connect( this, SIGNAL( signalStopActivity() ), this, SLOT( stopInternal() ));
@@ -2564,7 +2579,7 @@ bool Catalog::findNext(const FindOptions* findOpts, DocPosition& docPos, int& le
         if(findOpts->ignoreContextInfo)
         {
             contextInfoPos = miscOptions.contextInfo.search(targetStr);
-	    contextInfoLength = miscOptions.contextInfo.matchedLength();
+            contextInfoLength = miscOptions.contextInfo.matchedLength();
             if(contextInfoPos >= 0)
             {
                 targetStr.remove(contextInfoPos,contextInfoLength);
@@ -3029,7 +3044,7 @@ bool Catalog::findPrev(const FindOptions* findOpts, DocPosition& docPos, int& le
 
 
 Catalog::DiffResult Catalog::diff(uint entry, QString *result)
-{/*
+{
     if(!result)
     {
         kdWarning() << "0 pointer for result" << endl;
@@ -3040,9 +3055,9 @@ Catalog::DiffResult Catalog::diff(uint entry, QString *result)
     {
         return DiffNeedList;
     }
-                        */
+
     // first look if the diff for this entry is in the cache
-    QString *s = d->diffCache[entry];/*
+    QString *s = d->diffCache[entry];
     if(s)
     {
         if(s->isEmpty())
@@ -3052,11 +3067,11 @@ Catalog::DiffResult Catalog::diff(uint entry, QString *result)
         *result = *s;
         return DiffOk;
     }
-                        */
+
     // then look if the same msgid is contained in the diff file
     // FIXME: should care about plural forms in msgid
     QString id = msgid(entry).first();
-    /*id.replace( "\n","");
+    id.replace( "\n","");
     if(d->msgidDiffList.contains(id))
     {
 	// FIXME:: should care about plural forms in msgid
@@ -3069,7 +3084,7 @@ Catalog::DiffResult Catalog::diff(uint entry, QString *result)
     kdDebug(KBABEL) << "diffv active" << endl;
     d->_active=true;
     d->_stop=false;
-                        */
+
     QString idForDiff;
 
 
