@@ -39,6 +39,7 @@
 
 #include <qcombobox.h>
 
+#include <kapplication.h>
 #include <kmessagebox.h>
 #include <klineedit.h>
 #include <klocale.h>
@@ -72,6 +73,7 @@ ProjectWizard::ProjectWizard(QWidget *parent,const char *name)
    
     connect( _wizard->_projectName, SIGNAL(textChanged(const QString &)), this, SLOT(textChanged(const QString &)));
     connect( _wizard->_projectFile, SIGNAL(textChanged(const QString &)), this, SLOT(textChanged(const QString &)));
+    connect( this, SIGNAL( helpClicked( void ) ), this, SLOT( slotHelpClicked( void ) ) );
 
     addPage(_wizard, i18n("Basic Project Information"));
     
@@ -162,4 +164,9 @@ Project::Ptr ProjectWizard::newProject()
     return 0;
 }
 
+void ProjectWizard::slotHelpClicked( void )
+{
+    kapp->invokeHelp( "preferences-project-wizard", "kbabel" );
+}
+
 #include "projectwizard.moc"
