@@ -1,10 +1,9 @@
 /* ****************************************************************************
   This file is part of KBabel
 
-  Copyright (C) 1999-2001 by Matthias Kiefer
-                            <matthias.kiefer@gmx.de>
-		2002-2005  by Stanislav Visnovsky
-			    <visnovsky@kde.org>
+  Copyright (C) 1999-2001 by Matthias Kiefer <matthias.kiefer@gmx.de>
+		2002-2005 by Stanislav Visnovsky <visnovsky@kde.org>
+  Copyright (C) 2006 by Nicolas GOUTTE <goutte@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,6 +33,7 @@
 **************************************************************************** */
 #include "kbabel.h"
 #include "kbabeliface.h"
+#include "kbprojectmanager.h"
 #include "catalog.h"
 #include "kbabelsplash.h"
 #include "findoptions.h"
@@ -73,9 +73,17 @@ public:
 	QString findStr, QString replaceStr, int caseSensitive, int wholeWords, int isRegExp,
 	int inMsgid, int inMsgstr, int inComment,
 	int ignoreAccelMarker, int ignoreContextInfo, int ask, int askForNextFile, int askForSave);
+    virtual bool findInFile(QCString fileSource, QCString url,
+	QString findStr, int caseSensitive, int wholeWords, int isRegExp,
+	int inMsgid, int inMsgstr, int inComment,
+	int ignoreAccelMarker, int ignoreContextInfo, int askForNextFile, int askForSave, QCString project );
+    virtual bool replaceInFile(QCString fileSource, QCString url,
+	QString findStr, QString replaceStr, int caseSensitive, int wholeWords, int isRegExp,
+	int inMsgid, int inMsgstr, int inComment,
+	int ignoreAccelMarker, int ignoreContextInfo, int ask, int askForNextFile, int askForSave, QCString project );
     virtual void spellcheck(QStringList fileList);
 private:
-    KBabelMW* findInstance( QCString file, QString project, QCString package);
+    KBabelMW* findInstance( const KURL& url, const QString& project, const QString& package) const;
 };
 
 
@@ -139,9 +147,11 @@ int KBabelApp::newInstance()
 	{
 	    QFileInfo fi(projectFile);
 	    projectFile = fi.absFilePath();
-	} else
+	} 
+	else
 	{
-	    projectFile = KBABEL_DEFAULTPROJECT;
+	    projectFile = KBabel::ProjectManager::defaultProjectName();
+	    kdDebug(KBABEL) << "Using the default project Project: " << projectFile << endl;
 	}
 
 	kdDebug() << "Project: " << projectFile << endl;
@@ -153,7 +163,7 @@ int KBabelApp::newInstance()
 
 	    kdDebug () << "Resuming DCOP" << endl;
 	    kapp->dcopClient()->resume();
-            kbInterface->gotoFileEntry(args->url(0).url().utf8(),m.utf8());
+            kbInterface->gotoFileEntry(args->url(0).url().local8Bit(),m.utf8());
         }
         else
         {
@@ -215,12 +225,12 @@ KBabelInterface::KBabelInterface()
 
 void KBabelInterface::openURL(QCString url, QCString package, WId window, int newWindow)
 {
-    openURL(url,package,window,newWindow, KBABEL_DEFAULTPROJECT.local8Bit());
+    openURL(url,package,window,newWindow,  KBabel::ProjectManager::defaultProjectName().local8Bit());
 }
 
 void KBabelInterface::openURL(QCString url, QCString package, WId window, int newWindow, QCString projectFile)
 {
-    QString project(projectFile);
+    const QString project( QString::fromLocal8Bit( projectFile ) );
 
     kdDebug() << "openURL " << url << endl;
 
@@ -305,15 +315,15 @@ void KBabelInterface::openURL(QCString url, QCString package, WId window, int ne
 
 void KBabelInterface::openTemplate(QCString openFilename, QCString saveFilename, QCString package, int newWindow)
 {
-    openTemplate(openFilename, saveFilename, package, newWindow, KBABEL_DEFAULTPROJECT.local8Bit());
+    openTemplate(openFilename, saveFilename, package, newWindow, KBabel::ProjectManager::defaultProjectName().local8Bit());
 }
 
 void KBabelInterface::openTemplate(QCString openFilename, QCString saveFilename, QCString package, int newWindow, QCString projectFile)
 {
-    QString project(projectFile);
+    const QString project( QString::fromLocal8Bit( projectFile ) );
 
-    KURL u(saveFilename.data());
-    KURL t(openFilename.data());
+    const KURL u( QString::fromLocal8Bit( saveFilename ) );
+    const KURL t( QString::fromLocal8Bit( openFilename ) );
 
     kdDebug () << "Suspending DCOP" << endl;
     kapp->dcopClient()->suspend();
@@ -351,11 +361,12 @@ void KBabelInterface::openTemplate(QCString openFilename, QCString saveFilename,
 
 void KBabelInterface::gotoFileEntry(QCString url, QCString m)
 {
-    QString msgid = QString::fromUtf8(m);
-    KBabelMW *kb = findInstance( url, KBABEL_DEFAULTPROJECT, QCString() );
+    const KURL u( QString::fromLocal8Bit( url ) );
+    KBabelMW *kb = findInstance( u, KBabel::ProjectManager::defaultProjectName(), QString() );
 
     if(!kb) return;
 
+    QString msgid = QString::fromUtf8(m);
     int index = kb->m_view->catalog()->indexForMsgid(msgid);
     if(index >= 0)
     {
@@ -368,13 +379,14 @@ void KBabelInterface::gotoFileEntry(QCString url, QCString m)
 
 void KBabelInterface::gotoFileEntry(QCString url, QCString package, int m)
 {
-    gotoFileEntry(url, package, m, KBABEL_DEFAULTPROJECT.local8Bit() );
+    gotoFileEntry(url, package, m, KBabel::ProjectManager::defaultProjectName().local8Bit() );
 }
 
 void KBabelInterface::gotoFileEntry(QCString url, QCString package, int m, QCString projectFile)
 {
-    QString project(projectFile);
-    KBabelMW *kb = findInstance( url, projectFile, package );
+    const KURL u ( QString::fromLocal8Bit( url ) );
+    const QString p ( QString::fromUtf8( package ) ); // ### VERIFY encoding!
+    KBabelMW *kb = findInstance( u, projectFile, p );
 
     if(!kb) return;
 
@@ -388,10 +400,23 @@ bool KBabelInterface::findInFile(QCString fileSource, QCString url,
 	QString findStr, int caseSensitive, int wholeWords, int isRegExp,
 	int inMsgid, int inMsgstr, int inComment,
 	int ignoreAccelMarker, int ignoreContextInfo, int askForNextFile, int askForSave)
+{
+	// no project given, open with default project
+	return findInFile ( fileSource, url, findStr, caseSensitive, 
+                             wholeWords, isRegExp, inMsgid, inMsgstr, inComment, ignoreAccelMarker, ignoreContextInfo,
+                             askForNextFile, askForSave,
+			     KBabel::ProjectManager::defaultProjectName().utf8() );
+}
+
+bool KBabelInterface::findInFile(QCString fileSource, QCString url,
+	QString findStr, int caseSensitive, int wholeWords, int isRegExp,
+	int inMsgid, int inMsgstr, int inComment,
+	int ignoreAccelMarker, int ignoreContextInfo, int askForNextFile, int askForSave, QCString project )
 {
     kdDebug(KBABEL) << "findInFile (" <<fileSource<< "): " << url << " for " << findStr << endl;
 
-    KBabelMW *kb = findInstance(url, KBABEL_DEFAULTPROJECT, QCString());
+    const KURL u( QString::fromLocal8Bit( url ) );
+    KBabelMW *kb = findInstance( u, QString::fromLocal8Bit(project), QString() );
 
     if(!kb) return false;
 
@@ -418,10 +443,24 @@ bool KBabelInterface::replaceInFile(QCString fileSource, QCString url,
 	QString findStr, QString replaceStr, int caseSensitive, int wholeWords, int isRegExp,
 	int inMsgid, int inMsgstr, int inComment,
 	int ignoreAccelMarker, int ignoreContextInfo, int ask, int askForNextFile, int askForSave)
+{
+	return replaceInFile( fileSource, url,
+                               findStr, replaceStr, caseSensitive, wholeWords, isRegExp,
+                               inMsgid, inMsgstr, inComment, ignoreAccelMarker, ignoreContextInfo,
+                               ask, askForNextFile, askForSave,
+			       KBabel::ProjectManager::defaultProjectName().utf8() );	
+}
+
+bool KBabelInterface::replaceInFile(QCString fileSource, QCString url,
+	QString findStr, QString replaceStr, int caseSensitive, int wholeWords, int isRegExp,
+	int inMsgid, int inMsgstr, int inComment,
+	int ignoreAccelMarker, int ignoreContextInfo, int ask, int askForNextFile, int askForSave,
+        QCString project )
 {
     kdDebug(KBABEL) << "replaceInFile (" <<fileSource<< "): " << url << " for " << findStr << endl;
 
-    KBabelMW *kb = findInstance( url, KBABEL_DEFAULTPROJECT, QCString() );
+    const KURL u ( QString::fromLocal8Bit( url ) );
+    KBabelMW *kb = findInstance( u, QString::fromLocal8Bit(project), QString() );
 
     if( !kb ) return false;
 
@@ -448,22 +487,21 @@ bool KBabelInterface::replaceInFile(QCString fileSource, QCString url,
 
 void KBabelInterface::spellcheck(QStringList fileList)
 {
-    QCString nullString;
-    KBabelMW *kb = findInstance(nullString, KBABEL_DEFAULTPROJECT, nullString);
+    // ### FIXME: the default project might use the wrong language!
+    KBabelMW *kb = findInstance( KURL(), KBabel::ProjectManager::defaultProjectName(), QString() );
     kb->show();
     kb->spellcheckMoreFiles( fileList );
 }
 
-KBabelMW* KBabelInterface::findInstance( QCString url, QString project, QCString package)
+KBabelMW* KBabelInterface::findInstance( const KURL& url, const QString& project, const QString& package) const
 {
     kdDebug () << "Suspending DCOP" << endl;
     kapp->dcopClient()->suspend();
 
-    KURL u ( url );
     KBabelMW *kb = 0;
-    if( !url.isNull() )
+    if( !url.isEmpty() )
     {
-	kb = KBabelMW::winForURL(u,project);
+	kb = KBabelMW::winForURL( url, project );
 
 	if(kb)
 	{
@@ -484,7 +522,8 @@ KBabelMW* KBabelInterface::findInstance( QCString url, QString project, QCString
 	}
 
         kb->show();
-        if( !url.isEmpty() ) kb->open(u,QString::fromUtf8(package),false);
+        if ( !url.isEmpty() )
+            kb->open( url, package, false );
     }
 
     kdDebug () << "Resuming DCOP" << endl;
@@ -507,7 +546,7 @@ int main(int argc, char **argv)
 {
     KAboutData about("kbabel",I18N_NOOP("KBabel"),VERSION,
        I18N_NOOP("An advanced PO file editor"),KAboutData::License_GPL,
-       I18N_NOOP("(c) 1999,2000,2001,2002,2003,2004,2005 The KBabel developers"),0,"http://i18n.kde.org/tools/kbabel");
+       I18N_NOOP("(c) 1999,2000,2001,2002,2003,2004,2005,2006 The KBabel developers"),0,"http://kbabel.kde.org");
 
     about.addAuthor("Matthias Kiefer",I18N_NOOP("Original author"),"kiefer@kde.org");
     about.addAuthor("Wolfram Diestel"
@@ -522,7 +561,7 @@ int main(int argc, char **argv)
          ,"dubbleu@web.de");
     about.addAuthor("Asgeir Frimannsson",I18N_NOOP("Translation List View")
          ,"asgeirf@redhat.com");
-    about.addAuthor("Nicolas Goutte", I18N_NOOP("Filter improvements"), "goutte@kde.org");
+    about.addAuthor("Nicolas Goutte", I18N_NOOP("Current maintainer"), "goutte@kde.org");
 
     about.addCredit("Claudiu Costin",I18N_NOOP("Wrote documentation and sent "
 		"many bug reports and suggestions for improvements.")
@@ -541,10 +580,12 @@ int main(int argc, char **argv)
 					,"suse@suse.de","http://www.suse.de");
     about.addCredit("Trolltech", I18N_NOOP("KBabel contains code from Qt"), 0, "http://www.trolltech.com");
 
-    about.addCredit("Eva Brucherseifer", I18N_NOOP("String difference algorithm implementation"), "eva@kde.org");
+    about.addCredit("Eva Brucherseifer", I18N_NOOP("String distance algorithm implementation"), "eva@kde.org");
 
     about.addCredit("Albert Cervera Areny", I18N_NOOP("Error list for current entry, regexp data tool"), "albertca@hotpop.com");
 
+    about.addCredit("Nick Shaforostoff", I18N_NOOP("Word-by-word string difference algorithm implementation"), "shafff@ukr.net");
+
     // Initialize command line args
     KCmdLineArgs::init(argc, argv, &about);
 
