@@ -29,7 +29,7 @@ using namespace KCal;
 
 extern "C"
 {
-  void *init_kcal_bugzilla()
+  KDE_EXPORT void *init_kcal_bugzilla()
   {
     KGlobal::locale()->insertCatalogue( "kres_bugzilla" );
     return new KRES::PluginFactory<KCalResource,KCalResourceConfig>();
