@@ -1,8 +1,7 @@
 /***************************************************************************
-    begin                : Mon Jun 17 2002
-    copyright            : (C) 2002 by Luis De la Parra Blum
+    begin             : Mon Jun 17 2002
+    copyright         : (C) 2002 Luis De la Parra Blum <luis@delaparra.org>
                                         and Brian Thomas
-    email                : luis@delaparra.org
  ***************************************************************************/
 
 /***************************************************************************
@@ -12,7 +11,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2006                                               *
+ *   copyright (C) 2003-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -34,7 +33,7 @@
 
 #include "adawriter.h"
 #include "cppwriter.h"
-// #include "cswriter.h" // missing in action?!?
+#include "csharpwriter.h"
 #include "idlwriter.h"
 #include "javawriter.h"
 #include "pascalwriter.h"
@@ -84,11 +83,16 @@
 #include "rubycodecomment.h"
 #include "xmlcodecomment.h"
 
+#include "cppcodegenerationpolicy.h"
+#include "javacodegenerationpolicy.h"
+#include "rubycodegenerationpolicy.h"
+
 namespace CodeGenFactory {
 
 CodeGenerator* createObject(Uml::Programming_Language pl)  {
     CodeGenerator* obj = 0;
     Settings::OptionState optionState = Settings::getOptionState();
+    UMLApp::app()->setPolicyExt(NULL);
     switch (pl) {
         case Uml::pl_Ada:
             obj = new AdaWriter();
@@ -97,21 +101,32 @@ CodeGenerator* createObject(Uml::Programming_Language pl)  {
             obj = new ASWriter();
             break;
         case Uml::pl_Cpp:
-            if (optionState.generalState.newcodegen)
+            if (optionState.generalState.newcodegen) {
                 obj = new CPPCodeGenerator();
-            else
+                obj->connect_newcodegen_slots();
+            } else {
                 obj = new CppWriter();
+            }
+            {
+                CPPCodeGenerationPolicy *p =
+                    new CPPCodeGenerationPolicy(UMLApp::app()->getConfig());
+                UMLApp::app()->setPolicyExt(p);
+            }
+            break;
+        case Uml::pl_CSharp:
+            obj = new CSharpWriter();
             break;
-        // case Uml::pl_Csharp:
-        //     obj = new CsWriter();
-        //     break;
         case Uml::pl_IDL:
             obj = new IDLWriter();
             break;
         case Uml::pl_Java:
-            if (optionState.generalState.newcodegen)
+            if (optionState.generalState.newcodegen) {
                 obj = new JavaCodeGenerator();
-            else
+                obj->connect_newcodegen_slots();
+                JavaCodeGenerationPolicy *p =
+                    new JavaCodeGenerationPolicy(UMLApp::app()->getConfig());
+                UMLApp::app()->setPolicyExt(p);
+            } else
                 obj = new JavaWriter();
             break;
         case Uml::pl_JavaScript:
@@ -133,9 +148,13 @@ CodeGenerator* createObject(Uml::Programming_Language pl)  {
             obj = new PythonWriter();
             break;
         case Uml::pl_Ruby:
-            if (optionState.generalState.newcodegen)
+            if (optionState.generalState.newcodegen) {
                 obj = new RubyCodeGenerator();
-            else
+                obj->connect_newcodegen_slots();
+                RubyCodeGenerationPolicy *p =
+                    new RubyCodeGenerationPolicy(UMLApp::app()->getConfig());
+                UMLApp::app()->setPolicyExt(p);
+            } else
                 obj = new RubyWriter();
             break;
         case Uml::pl_SQL:
@@ -152,7 +171,8 @@ CodeGenerator* createObject(Uml::Programming_Language pl)  {
                         << ". Type unknown" << endl;
             break;
     }
-    obj->initFromParentDocument();
+    if (obj)
+        obj->initFromParentDocument();
     return obj;
 }
 
@@ -175,6 +195,8 @@ CodeDocument * newClassifierCodeDocument (UMLClassifier * c)
         default:
             break;
     }
+    retval->initCodeClassFields();
+    retval->synchronize();
     return retval;
 }
 
@@ -219,6 +241,7 @@ CodeClassField * newCodeClassField(ClassifierCodeDocument *ccd, UMLAttribute *at
         default:
             break;
     }
+    retval->finishInitialization();
     return retval;
 }
 
