@@ -5,7 +5,7 @@
     source code is not replicated in the XMI file.
                              -------------------
     copyright            : (C) 2003 Brian Thomas
-         (C) 2004  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
+         (C) 2004  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,6 +21,7 @@
 #define CPPWRITER_H
 
 #include "simplecodegenerator.h"
+#include "cppcodegenerationpolicy.h"
 #include "../umloperationlist.h"
 #include "../umlattributelist.h"
 #include "../umlassociationlist.h"
@@ -31,7 +32,7 @@ class ClassifierInfo;
 /**
   * class CppWriter is a code generator for UMLClassifier objects.
   * Create an instance of this class, and feed it a UMLClassifier when
-  * calling writeClass and it will generate both a header (.h) and 
+  * calling writeClass and it will generate both a header (.h) and
   * source (.cpp) file for that classifier.
   */
 class CppWriter : public SimpleCodeGenerator {
@@ -77,7 +78,7 @@ private:
     void writeClassDecl(UMLClassifier *c, QTextStream &cpp);
 
     /**
-     * Writes the comment and class constructor declaration or methods 
+     * Writes the comment and class constructor declaration or methods
      */
     void writeConstructorDecls(QTextStream &h);
     void writeConstructorMethods(QTextStream &cpp);
@@ -89,7 +90,7 @@ private:
     void writeFieldDecl(UMLClassifier *c, Uml::Visibility permitScope, QTextStream &stream);
 
     /**
-     * write all method declarations, for attributes and associations 
+     * write all method declarations, for attributes and associations
      * for the given permitted scope.
      */
     void writeAccessorMethodDecl(UMLClassifier *c, Uml::Visibility permitScope, QTextStream &stream);
@@ -168,15 +169,17 @@ private:
      * writeVectorAttributeAccessorMethods() on the association
      * role
      */
-    void writeAssociationRoleMethod(QString fieldClassName, bool isHeaderMethod, bool writeMethodBody, QString roleName, QString multi,
-                                    QString description, Uml::Changeability_Type change,
+    void writeAssociationRoleMethod(const QString &fieldClassName, bool isHeaderMethod, bool writeMethodBody,
+                                    const QString &roleName, const QString &multi,
+                                    const QString &description, Uml::Changeability_Type change,
                                     QTextStream &stream);
 
     /**
      * Writes getFoo() and setFoo() accessor methods for the attribute
      */
-    void writeSingleAttributeAccessorMethods(QString fieldClassName, QString fieldVarName,
-            QString fieldName, QString description,
+    void writeSingleAttributeAccessorMethods(
+            const QString &fieldClassName, const QString &Name,
+            const QString &fieldName, const QString &description,
             Uml::Changeability_Type change,
             bool isHeaderMethod,
             bool isStatic, bool writeMethodBody, QTextStream &cpp);
@@ -184,8 +187,9 @@ private:
     /**
      * Writes addFoo() and removeFoo() accessor methods for the Vector attribute
      */
-    void writeVectorAttributeAccessorMethods(QString fieldClassName, QString fieldVarName,
-            QString fieldName, QString description,
+    void writeVectorAttributeAccessorMethods(
+            const QString &fieldClassName, const QString &fieldVarName,
+            const QString &fieldName, const QString &description,
             Uml::Changeability_Type change,
             bool isHeaderMethod,
             bool writeMethodBody,
@@ -194,7 +198,7 @@ private:
     /**
      * Writes a // style comment
      */
-    void writeComment(QString text, QString indent, QTextStream &cpp);
+    void writeComment(const QString &text, const QString &indent, QTextStream &cpp);
 
     /**
      * Writes a documentation comment
@@ -216,7 +220,8 @@ private:
      * utility method to break up a block of text, which has embedded newline chars,
      * and print them to a stream as separate lines of text, indented as directed.
      */
-    void printTextAsSeparateLinesWithIndent (QString text, QString indent, QTextStream &stream);
+    void printTextAsSeparateLinesWithIndent (const QString &text, const QString &indent,
+                                             QTextStream &stream);
 
     /**
      * Intellegently print out header include/forward decl. for associated classes.
@@ -241,17 +246,17 @@ private:
     /**
      * Raises the case of the first letter in the given string
      */
-    QString capitalizeFirstLetter(QString string);
+    QString capitalizeFirstLetter(const QString &string);
 
     /**
      * Replaces `string' with STRING_TYPENAME.
      */
-    QString fixTypeName(QString string);
+    QString fixTypeName(const QString &string);
 
     /**
      * check that initial values of strings have quotes around them
      */
-    QString fixInitialStringDeclValue(QString value, QString type);
+    QString fixInitialStringDeclValue(const QString &value, const QString &type);
 
     /**
      * Determine what the variable name of this attribute should be.
@@ -264,58 +269,24 @@ private:
     void writeBlankLine(QTextStream &stream);
 
     /**
-     * Basic "unit" of indentation 
+     * Return the policy object
      */
-    QString INDENT;
+    CPPCodeGenerationPolicy *policyExt();
 
     /**
      * Summary information about current classifier.
      */
     ClassifierInfo * m_classifierInfo;
 
-    /**
-     * When we create a string variable, what do we use? this is the default..
-     */
-    QString STRING_TYPENAME;
-    QString STRING_TYPENAME_INCLUDE;
-
-    /**
-     * When we create a 'vector' variable, what do we use? this is the default..
-     */
-    QString VECTOR_TYPENAME;
-    QString VECTOR_TYPENAME_INCLUDE;
     QString VECTOR_METHOD_APPEND;
     QString VECTOR_METHOD_REMOVE;
     QString VECTOR_METHOD_INIT;
     QString OBJECT_METHOD_INIT;
 
     /**
-     * Create various methods for class attributes/associations/operations as inline decl in header.
+     * Create association methods for class attributes/associations/operations as inline decl in header.
      */
-    bool INLINE_ATTRIBUTE_METHODS;
     bool INLINE_ASSOCIATION_METHODS;
-    bool INLINE_OPERATION_METHODS;
-
-    /**
-     * Control whether or not we want to write the package name as a namespace
-     * in our class.
-     */
-    bool WRITE_PACKAGE_NAMESPACE;
-    /**
-     * Constrol whether or not we want to have a constructor/destructor written
-     */
-    bool WRITE_EMPTY_CONSTRUCTOR;
-    bool WRITE_EMPTY_DESTRUCTOR;
-
-    /**
-     * Control whether we want accessor methods generated for attributes.
-     */
-    bool WRITE_ATTRIBUTE_ACCESSOR_METHODS;
-
-    /**
-     * Should destuctors be declared as virtual?
-     */
-    bool WRITE_VIRTUAL_DESTRUCTORS;
 
     QStringList ObjectFieldVariables;
     QStringList VectorFieldVariables;
