@@ -13,31 +13,35 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2006-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
+// own header
+#include "rubycodegenerator.h"
+
+// qt/kde includes
+#include <qregexp.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
-#include <qregexp.h>
-
-#include "rubycodegenerator.h"
+// local includes
 #include "rubycodecomment.h"
 #include "codeviewerdialog.h"
+#include "../uml.h"
 
 // Constructors/Destructors
 //
 
 RubyCodeGenerator::RubyCodeGenerator (QDomElement & elem )
+  : CodeGenerator(elem)
 {
-    initFields();
-    loadFromXMI(elem);
 }
 
 RubyCodeGenerator::RubyCodeGenerator ()
 {
-    initFields();
 }
 
 RubyCodeGenerator::~RubyCodeGenerator ( ) { }
@@ -63,29 +67,8 @@ CodeViewerDialog * RubyCodeGenerator::getCodeViewerDialog ( QWidget* parent, Cod
 }
 
 
-void RubyCodeGenerator::setPolicy ( CodeGenerationPolicy* policy )
-{
-    RubyCodeGenerationPolicy * rpolicy = dynamic_cast<RubyCodeGenerationPolicy*>(policy);
-    CodeGenerator::setPolicy(policy);
-    setRubyPolicy(rpolicy);
-}
-
-void RubyCodeGenerator::setRubyPolicy( RubyCodeGenerationPolicy * policy) {
-    m_rubycodegenerationpolicy = policy;
-}
-
 RubyCodeGenerationPolicy * RubyCodeGenerator::getRubyPolicy() {
-    return m_rubycodegenerationpolicy;
-}
-
-RubyCodeGenerationPolicy::RubyCommentStyle RubyCodeGenerator::getCommentStyle ( )
-{
-    return getRubyPolicy()->getCommentStyle();
-}
-
-bool RubyCodeGenerator::getAutoGenerateConstructors ( )
-{
-    return getRubyPolicy()->getAutoGenerateConstructors();
+    return dynamic_cast<RubyCodeGenerationPolicy*>(UMLApp::app()->getPolicyExt());
 }
 
 bool RubyCodeGenerator::getAutoGenerateAttribAccessors ( )
@@ -105,44 +88,37 @@ QString RubyCodeGenerator::getListFieldClassName () {
 // Other methods
 //
 
-QString RubyCodeGenerator::capitalizeFirstLetter(QString string)
+QString RubyCodeGenerator::capitalizeFirstLetter(const QString &string)
 {
     // we could lowercase everything tostart and then capitalize? Nah, it would
     // screw up formatting like getMyRadicalVariable() to getMyradicalvariable(). Bah.
     QChar firstChar = string.at(0);
-    string.replace( 0, 1, firstChar.upper());
-    return string;
+    return firstChar.upper() + string.mid(1);
 }
 
-QString RubyCodeGenerator::cppToRubyType(QString typeStr) {
-    typeStr = cleanName(typeStr);
-    typeStr.replace("const ", "");
-    typeStr.replace(QRegExp("[*&\\s]"), "");
-    typeStr.replace(QRegExp("[<>]"), "_");
-    typeStr.replace("QStringList", "Array");
-    typeStr.replace(QRegExp("^string$"),"String");
-    typeStr.replace("QString", "String");
-    typeStr.replace("bool", "true|false");
-    typeStr.replace(QRegExp("^(uint|int|ushort|short|ulong|long)$"), "Integer");
-    typeStr.replace(QRegExp("^(float|double)$"), "Float");
-    typeStr.replace(QRegExp("^Q(?=[A-Z])"), "Qt::");
-    typeStr.replace(QRegExp("^K(?!(DE|Parts|IO)"), "KDE::");
+QString RubyCodeGenerator::cppToRubyType(const QString &typeStr) {
+    QString type = cleanName(typeStr);
+    type.replace("const ", "");
+    type.replace(QRegExp("[*&\\s]"), "");
+    type.replace(QRegExp("[<>]"), "_");
+    type.replace("QStringList", "Array");
+    type.replace(QRegExp("^string$"),"String");
+    type.replace("QString", "String");
+    type.replace("bool", "true|false");
+    type.replace(QRegExp("^(uint|int|ushort|short|ulong|long)$"), "Integer");
+    type.replace(QRegExp("^(float|double)$"), "Float");
+    type.replace(QRegExp("^Q(?=[A-Z])"), "Qt::");
+    type.replace(QRegExp("^K(?!(DE|Parts|IO)"), "KDE::");
 
-    return typeStr;
+    return type;
 }
 
-QString RubyCodeGenerator::cppToRubyName(QString nameStr) {
-    nameStr = cleanName(nameStr);
-    nameStr.replace(QRegExp("^m_"), "");
-    nameStr.replace(QRegExp("^[pbn](?=[A-Z])"), "");
-    nameStr = nameStr.mid(0, 1).lower() + nameStr.mid(1);
-    return nameStr;
-}
-
-CodeGenerationPolicy * RubyCodeGenerator::newCodeGenerationPolicy( KConfig * config)
-{
-    CodeGenerationPolicy * myPolicy = new RubyCodeGenerationPolicy(config);
-    return myPolicy;
+QString RubyCodeGenerator::cppToRubyName(const QString &nameStr) {
+    QString name = cleanName(nameStr);
+    name.replace(QRegExp("^m_"), "");
+    name.replace(QRegExp("^[pbn](?=[A-Z])"), "");
+    name = name.mid(0, 1).lower() + name.mid(1);
+    return name;
 }
 
 /**
@@ -151,21 +127,18 @@ CodeGenerationPolicy * RubyCodeGenerator::newCodeGenerationPolicy( KConfig * con
  */
 CodeDocument * RubyCodeGenerator::newClassifierCodeDocument ( UMLClassifier * c)
 {
-    RubyClassifierCodeDocument * doc = new RubyClassifierCodeDocument(c,this);
+    RubyClassifierCodeDocument * doc = new RubyClassifierCodeDocument(c);
+    doc->initCodeClassFields();
     return doc;
 }
 
-CodeComment * RubyCodeGenerator::newCodeComment ( CodeDocument * doc) {
-    return new RubyCodeComment(doc);
-}
-
+/* These initializations are done in CodeGenFactory::createObject()
 void RubyCodeGenerator::initFields() {
-
-    setPolicy ( new RubyCodeGenerationPolicy(getPolicy()) );
-
+    UMLApp::app()->setPolicyExt ( new RubyCodeGenerationPolicy(UMLApp::app()->getConfig()) );
     // load Classifier documents from parent document
     initFromParentDocument();
 }
+ */
 
 const QStringList RubyCodeGenerator::reservedKeywords() const {
 
