@@ -2,7 +2,7 @@
     begin               : Thu Jul 26 2005
     copyright           : (C) 2005 by Rene Meyer
     email               : rene.meyer@sturmit.de
-      (C) 2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net> 
+      (C) 2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
  ***************************************************************************/
 
 /***************************************************************************
@@ -33,7 +33,7 @@
 #include "../classifierlistitem.h"
 #include "../model_utils.h"
 
-static const char *words[] = {
+static const char *tclwords[] = {
                                  "body",
                                  "break",
                                  "case",
@@ -943,8 +943,8 @@ TclWriter::reservedKeywords() const
 
     if              (keywords.isEmpty())
     {
-        for (int i = 0; words[i]; i++)
-            keywords.append(words[i]);
+        for (int i = 0; tclwords[i]; i++)
+            keywords.append(tclwords[i]);
     }
     return          keywords;
 }
