@@ -6,7 +6,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2002-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -37,7 +37,6 @@
 #include "../operation.h"
 #include "../classifier.h"
 #include "../template.h"
-#include "../umldoc.h"
 #include "../listpopupmenu.h"
 #include "../umlattributelist.h"
 #include "../classifierlistitem.h"
@@ -64,6 +63,10 @@ void UMLOperationDialog::setupDialog() {
 
     m_pGenGB = new QGroupBox(i18n("General Properties"), plainPage() );
     QGridLayout * genLayout = new QGridLayout(m_pGenGB, 3, 4 );
+    genLayout -> setColStretch(1, 1);
+    genLayout -> setColStretch(3, 1);
+    genLayout -> addColSpacing(1, 200);
+    genLayout -> addColSpacing(3, 200);
     genLayout -> setMargin(margin);
     genLayout -> setSpacing(10);
 
@@ -105,10 +108,10 @@ void UMLOperationDialog::setupDialog() {
 
     m_pPrivateRB = new QRadioButton(i18n("P&rivate"), m_pScopeBG);
     scopeLayout -> addWidget(m_pPrivateRB);
-    
+
     m_pProtectedRB = new QRadioButton(i18n("Prot&ected"), m_pScopeBG);
     scopeLayout -> addWidget(m_pProtectedRB);
-    
+
     m_pImplementationRB = new QRadioButton(i18n("I&mplementation"), m_pScopeBG);
     scopeLayout -> addWidget(m_pImplementationRB);
 
@@ -189,12 +192,12 @@ void UMLOperationDialog::setupDialog() {
         insertType( m_pOperation->getTypeName(), 0 );
         m_pRtypeCB->setCurrentItem(0);
     }
-    
+
     //fill in parm list box
-    UMLAttributeList * list = m_pOperation -> getParmList();
+    UMLAttributeList list = m_pOperation->getParmList();
     UMLAttribute * pAtt = 0;
-    for( pAtt = list -> first(); pAtt != 0; pAtt = list -> next() )
-        m_pParmsLB -> insertItem( pAtt -> getName() );
+    for (pAtt = list.first(); pAtt; pAtt = list.next())
+        m_pParmsLB->insertItem( pAtt->getName() );
 
     //set scope
     Uml::Visibility scope = m_pOperation -> getVisibility();
@@ -365,7 +368,7 @@ void UMLOperationDialog::slotParameterProperties() {
     pOldAtt = m_pOperation->findParm( m_pParmsLB->currentText() );
 
     if( !pOldAtt ) {
-        kdDebug() << "THE impossible has occurred for:" << m_pParmsLB->currentText() << endl;
+        kDebug() << "THE impossible has occurred for:" << m_pParmsLB->currentText() << endl;
         return;
     }//should never occur
     ParmPropDlg dlg(this, m_doc, pOldAtt);
@@ -394,7 +397,7 @@ void UMLOperationDialog::slotParameterProperties() {
                 }
                 if (obj == NULL) {
                     // Nothing found: set type name directly. Bad.
-                    kdDebug() << "UMLOperationDialog::slotParameterProperties: "
+                    kDebug() << "UMLOperationDialog::slotParameterProperties: "
                     << typeName << " not found." << endl;
                     pOldAtt->setTypeName( typeName );  // Bad.
                 }
@@ -412,7 +415,7 @@ void UMLOperationDialog::slotParameterProperties() {
 
 void UMLOperationDialog::slotParameterUp()
 {
-    kdDebug() << k_funcinfo << endl;
+    kDebug() << k_funcinfo << endl;
     UMLAttribute* pOldAtt = m_pOperation->findParm( m_pParmsLB->currentText() );
 
     m_pOperation->moveParmLeft( pOldAtt );
