@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2002-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,7 +5,14 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2002-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
+
+// own header
+#include "linepath.h"
+
+// system includes
 #include <cstdlib>
 #include <cmath>
 
@@ -29,7 +31,6 @@
 #include "umlview.h"
 #include "umldoc.h"
 #include "uml.h"
-#include "linepath.h"
 
 LinePath::Circle::Circle(QCanvas * canvas, int radius /* = 0 */)
         : QCanvasEllipse(radius * 2, radius * 2, canvas) {
@@ -70,6 +71,7 @@ LinePath::LinePath() {
     m_pAssociation = 0;
     m_bHeadCreated = false;
     m_bParallelLineCreated = false;
+    m_DockRegion = TopBottom;
 }
 
 LinePath::~LinePath() {}
@@ -820,7 +822,7 @@ uint LinePath::getLineWidth() {
     if ( viewLineWidth >= 0 && viewLineWidth <= 10 )
         return viewLineWidth;
     else {
-        kdWarning() << "Ignore wrong LineWidth of " << viewLineWidth
+        kWarning() << "Ignore wrong LineWidth of " << viewLineWidth
         << " in LinePath::getLineWidth" << endl;
         return 0;
     }
@@ -864,7 +866,7 @@ void LinePath::dumpPoints () {
     int count = m_LineList.count();
     for( int i = 1; i < count; i++ ) {
         QPoint point = getPoint( i );
-        kdDebug()<<" * point x:"<<point.x()<<" y:"<<point.y()<<endl;
+        kDebug()<<" * point x:"<<point.x()<<" y:"<<point.y()<<endl;
     }
 }
 
