@@ -5,8 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
- *   Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                 *
+ *   copyright (C) 2002-2007                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef MESSAGEWIDGET_H
@@ -214,7 +214,7 @@ public:
      * Activates a MessageWidget.  Connects its m_pOw[] pointers
      * to UMLObjects and also send signals about its FloatingTextWidget.
      */
-    void activate(IDChangeLog * Log = 0);
+    bool activate(IDChangeLog * Log = 0);
 
     /**
      * Calculates the size of the widget by calling
@@ -378,6 +378,13 @@ private:
     ObjectWidget * m_pOw[2];
     FloatingTextWidget * m_pFText;
     int m_nY;
+    /**
+     * The following variables are used by loadFromXMI() as an intermediate
+     * store. activate() resolves the IDs, i.e. after activate() the variables
+     * m_pOw[] and m_pFText can be used.
+     */
+    Uml::IDType m_widgetAId, m_widgetBId, m_textId;
+
 public slots:
     void slotWidgetMoved(Uml::IDType id);
     void slotMenuSelection(int sel);
