@@ -1,8 +1,3 @@
-/*
- *  copyright (C) 2003-2004
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>
- */
-
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -10,6 +5,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   copyright (C) 2003-2006                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef UMLROLE_H
@@ -66,20 +63,6 @@ public:
      */
     QString getMultiplicity() const;
 
-    /**
-     * Returns the name assigned to the role.
-     *
-     * @return  The name assigned to the role.
-     */
-    QString getName() const;
-
-    /**
-     * Returns the documentation for the role.
-     *
-     * @return  The documentation text for the role.
-     */
-    QString getDoc() const;
-
     /**
      * Sets the UMLObject playing the role in the association.
      *
@@ -101,26 +84,8 @@ public:
      */
     void setMultiplicity ( const QString &multi );
 
-    /**
-     * Sets the name of the role.
-     *
-     * @param roleName  The name of role.
-     */
-    void setName( const QString &roleName );
-
-    /**
-     *  Sets the documentation on the role.
-     *
-     *  @param doc              The string with the documentation.
-     */
-    void setDoc( const QString &doc );
-
     UMLAssociation * getParentAssociation ();
 
-    // Sets the m_SecondaryId
-    // @todo  Candidate for removal
-    void setIdStr( const QString &idStr );
-
     /** get the 'id' of the role (NOT the parent object). This could be
      * either Uml::A or Uml::B. Yes, it would be better if we
      * could get along without this, but we need it to distinguish saved
@@ -152,13 +117,10 @@ private:
     /** do some initialization at construction time */
     void init (UMLAssociation * parent, UMLObject * parentObj, Uml::Role_Type r);
 
-    QString m_Doc;
     UMLAssociation * m_pAssoc;
     Uml::Role_Type m_role;
-    QString m_Name;
     QString m_Multi;
     Uml::Changeability_Type m_Changeability;
-
 };
 
 #endif
